#
# spec file for package xdm
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _dminitdir %{_libexecdir}/X11/displaymanagers

Name:           xdm
Version:        1.1.10
Release:        0
Summary:        X Display Manager
License:        MIT
Group:          System/X11/Utilities
Url:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.bz2
Source1:        xdm.tar.bz2
Source2:        HOWTO.xdm
Patch0:         xdm-consolekit.diff
Patch1:         xdm-tolerant-hostname-changes.diff
Patch2:         U_xdm_config-AC_LIBTOOL_DLOPEN-is-required-for-dynamic-lin.patch
Patch3:         U_xdm_config-use-libtool-export-dynamic-option-for-reverse.patch
Patch4:         U_xdm_Fix-missing-linking-dependency-on-ldl.patch
BuildRequires:  ConsoleKit-devel
%if 0%{?suse_version} >= 01140
# Needed to create the man page symlink to init.d
BuildRequires:  aaa_base-extras
%endif
# needed for patch0, patch2, patch3, patch4
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xdmcp)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.4
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xt)
Requires:       ConsoleKit
Requires:       logrotate
Requires:       sessreg
Requires:       xrdb
Requires:       xterm
Recommends:     dbus-1-x11
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Xdm manages a collection of X displays, which may be on the local host
or remote servers.

%prep
%setup -q
cp %{SOURCE2} .
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
# needed for patch0, patch2, patch3, patch4
autoreconf -fi

%build
%configure \
        --disable-static \
        --with-pam \
        --with-xdmconfigdir=%{_sysconfdir}/X11/xdm \
        --with-xdmscriptdir=%{_sysconfdir}/X11/xdm
make %{?_smp_mflags}

%install
%make_install
# Not used anymore by SuSE
rm %{buildroot}%{_sysconfdir}/X11/xdm/{GiveConsole,TakeConsole,Xsetup_0}

pushd %{buildroot}
# SuSE default XDM configuration
tar xf %{SOURCE1}
%ifarch s390 s390x
sed -i -e "s+DISPLAYMANAGER_REMOTE_ACCESS=.*+DISPLAYMANAGER_REMOTE_ACCESS=\"yes\"+g" \
       -e "s+DISPLAYMANAGER_REMOTE_ACCESS=.*+DISPLAYMANAGER_REMOTE_ACCESS=\"no\"+g" \
    var/adm/fillup-templates/sysconfig.displaymanager
%endif
popd

# Correct location (FHS-2.1)
ln -s %{_localstatedir}/lib/xdm/authdir %{buildroot}%{_sysconfdir}/X11/xdm/authdir
# bnc#223734
rm %{buildroot}%{_libdir}/X11/xdm/libXdmGreet.la
# for FHS compliance (bnc#21857)
mv %{buildroot}%{_libdir}/X11/xdm/chooser %{buildroot}%{_bindir}
# fdo#35868 (closed INVALID, but because of above fix, we want it)
ln -s xdm.1%{?ext_man} %{buildroot}%{_mandir}/man1/chooser.1%{?ext_man}
# missing manual page
mkdir -p %{buildroot}%{_mandir}/man8
ln -s ../man7/init.d.7%{?ext_man} %{buildroot}%{_mandir}/man8/rcxdm.8%{?ext_man}

# Note:
#   no %%stop_on_removal in %%preun
#   no %%restart_on_update in %%postun
# => we don't want to end an existing session

%post
%{fillup_and_insserv -Y xdm}
%{fillup_only -n displaymanager}

%postun
%{insserv_cleanup}

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%doc HOWTO.xdm
%dir %{_dminitdir}
%{_dminitdir}/xdm
%{_dminitdir}/entrance.fallback
%{_dminitdir}/gdm.fallback
%{_dminitdir}/kdm.fallback
%{_dminitdir}/lxdm.fallback
%{_dminitdir}/slim.fallback
%{_dminitdir}/wdm.fallback
%config %{_sysconfdir}/X11/xdm/
%config(noreplace) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/xdmcp
%{_sysconfdir}/init.d/xdm
%config %{_sysconfdir}/logrotate.d/xdm
%config %{_sysconfdir}/pam.d/xdm
%config %{_sysconfdir}/pam.d/xdm-np
%dir %{_localstatedir}/lib/xdm/
%{_localstatedir}/adm/fillup-templates/sysconfig.displaymanager
%{_localstatedir}/lib/xdm/authdir/
%ghost %{_localstatedir}/log/xdm.errors
%ghost %{_localstatedir}/run/xdm.pid
%{_bindir}/chooser
%{_bindir}/xdm
%{_bindir}/xdmshell
%{_sbindir}/rcxdm
%{_libdir}/X11/xdm/
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/Chooser
%{_mandir}/man1/chooser.1%{?ext_man}
%{_mandir}/man1/xdm.1%{?ext_man}
%{_mandir}/man8/rcxdm.8%{?ext_man}
%ifnarch %ix86
%dir %{_libdir}/X11
%endif

%changelog
